Prerequisites:

From standard python:
- Numpy
- Scipy (that requires LAPACK, fortran compiler, and fftw)

Other packages
- NeuroTools (http://neuralensemble.org/trac/NeuroTools)
- pyST (python Spike Toolbox)

To install:

$ python setup.py install

To install to an alternative directory:

$ python setup.py install --prefix=/other/directory

be sure that /other/directory is in the PYTHONPATH environnement variable. (type export PYTHONPATH="/other/directory" at command line)
